###########################################################
# R code
# File: logpost.r
#
# Example 17 in the paper by Amendola and Francq (2009)
# Specification of the unnormalized log-density of the 
# posterior distribution (up to a constant).
#
# Reference:
# Amendola, A. and Francq, C. (2009).
#   Concepts and tools for nonlinear time series modelling.
#   MPRA Paper No. 15140. Available at 
#   htttp://mpra.ub.uni-muenchen.de/15140/, and for a more
#   recent version htttp://mpra.ub.uni-muenchen.de/16668/
############################################################

logpost <- function(theta, y){
 n      <- length(y);
 a0     <- theta[1];
 a1     <- theta[2];
 b0     <- theta[3];
 b1     <- theta[4]
 gamma  <- theta[5]; 
 c      <- 0; 
 sig2   <- theta[6];
 
 if (gamma<=0) return(-Inf); 
 if (sig2<=0)  return(-Inf);
 
 logi     <- 1/(1+exp(-gamma*(y[1:(n-1)]-c)));
 ychap    <- (a0+a1*y[1:(n-1)])*(1-logi)+(b0+b1*y[1:(n-1)])*logi;
 loglike  <- -sum((y[2:n]-ychap)^2/(2*sig2))-(n-1)*log(sig2)/2;
 logprior <- -(a0^2+a1^2+b0^2+b1^2)/2 - gamma -2*log(sig2)-1/sig2;
return(loglike+logprior)}